<?php

namespace KnitPay\Extensions\RestroPress;

use Pronamic\WordPress\Money\Money;
use Pronamic\WordPress\Money\TaxedMoney;
use Pronamic\WordPress\Money\Parser as MoneyParser;
use Pronamic\WordPress\Pay\Payments\PaymentLines;
use Pronamic\WordPress\Pay\Payments\PaymentData as Pay_PaymentData;
use Pronamic\WordPress\Pay\Payments\Item;
use Pronamic\WordPress\Pay\Payments\Items;
use Pronamic\WordPress\Pay\Payments\PaymentDataInterface as Pronamic_Pay_PaymentDataInterface;

/**
 * Title: Restro Press extension
 * Description:
 * Copyright: 2020 Knit Pay
 * Company: Knit Pay
 *
 * @author  knitpay
 * @since   2.6
 */
class PaymentData extends Pay_PaymentData {


	/**
	 * Constructs and initializes an LearnPress payment data object.
	 *
	 * @param    $purchase_data array Cart details
	 * @param   $payment_id int .
	 */
	public function __construct( $purchase_data, $payment_id ) {
		$this->purchase_data = $purchase_data;
		$this->order_id      = $payment_id;
		$this->user_info     = $this->purchase_data['user_info'];
		$this->post_data     = $this->purchase_data['post_data'];

		parent::__construct();
	}

	/**
	 * Get source indicator
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_source()
	 * @return string
	 */
	public function get_source() {
		return 'restropress';
	}

	/**
	 * Get source ID.
	 *
	 * @return string
	 */
	public function get_source_id() {
		return $this->order_id;
	}

	/**
	 * Get title.
	 *
	 * @return string
	 */
	public function get_title() {
		/* translators: %s: order id */
		return sprintf( __( 'Restro Press Order  %s', 'knit-pay' ), $this->get_order_id() );
	}

	/**
	 * Get description
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_description()
	 * @return string
	 */
	public function get_description() {
		$description = rpress_get_option( $this->purchase_data['gateway'] . '_payment_description' );

		if ( empty( $description ) ) {
			$description = $this->get_title();
		}

		// Replacements.
		$replacements = array(
			'{order_id}' => $this->get_order_id(),
		);

		return strtr( $description, $replacements );
	}

	/**
	 * Get order ID
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_order_id()
	 * @return string
	 */
	public function get_order_id() {
		return $this->order_id;
	}

	/**
	 * Get items
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_items()
	 * @return Items
	 */
	/*
	  public function get_items() {

		$payment_lines = new PaymentLines();
		if ( $items = LP()->get_cart()->get_items() ) {
			foreach ( $items as $item ) {

					$line = $payment_lines->new_line();

					$line->set_id( $item['item_id'] );
					$line->set_name( get_the_title( $item['item_id'] ) );
					$line->set_quantity( $item['quantity'] );
					$line->set_discount_amount( new Money($item['data']->get_sale_price(), $this->get_currency_alphabetic_code()) );
					$line->set_unit_price( new TaxedMoney($item['data']->get_origin_price(), $this->get_currency_alphabetic_code()) );
					$line->set_total_amount( new TaxedMoney($item['data']->get_sale_price(), $this->get_currency_alphabetic_code()) );
					$line->set_product_url( get_permalink( $item['item_id'] ) );
				}
			}

			ppp($payment_lines);ddd();
	} */
	public function get_items() {

	}

	public function get_amount() {
		$amount = new TaxedMoney( $this->purchase_data['price'], $this->get_currency_alphabetic_code() );
		return $amount;

		/*
		 $total = 0;
		if ( $items = LP()->get_cart()->get_items() ) {
			foreach ( $items as $item ) {
			   $total += $item['total'];
			}
		}
		$amount = new TaxedMoney($total,$this->get_currency_alphabetic_code());
		return $amount; */
	}

	/**
	 * Get currency
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_currency_alphabetic_code()
	 * @return string
	 */
	public function get_currency_alphabetic_code() {
		return rpress_get_currency();
	}

	/**
	 * Get email.
	 *
	 * @return string
	 */
	public function get_email() {
		return $this->user_info['email'];
	}

	/**
	 * Get first name.
	 *
	 * @return string
	 */
	public function get_first_name() {
		if ( isset( $this->user_info['first_name'] ) ) {
			return $this->user_info['first_name'];
		}
	}

	/**
	 * Get last name.
	 *
	 * @return string
	 */
	public function get_last_name() {
		if ( isset( $this->user_info['last_name'] ) ) {
			return $this->user_info['last_name'];
		}
	}

	/**
	 * Get customer name.
	 *
	 * @return string
	 */
	public function get_customer_name() {
		return $this->get_first_name() . ' ' . $this->get_last_name();
	}

	/**
	 * Get address.
	 *
	 * @return null|string
	 */
	public function get_address() {
		if ( isset( $this->post_data['rpress_street_address'] ) ) {
			return $this->post_data['rpress_street_address'];
		}
	}

	/**
	 * Get city.
	 *
	 * @return null|string
	 */
	public function get_city() {
		if ( isset( $this->post_data['rpress_city'] ) ) {
			return $this->post_data['rpress_city'];
		}
	}

	/**
	 * Get ZIP.
	 *
	 * @return null|string
	 */
	public function get_zip() {
		if ( isset( $this->post_data['rpress_postcode'] ) ) {
			return $this->post_data['rpress_postcode'];
		}
	}

	/**
	 * Get telephone number.
	 *
	 * @return null|string
	 */
	public function get_telephone_number() {
		return $this->post_data['rpress_phone'];
	}
}
